pub enum BoardError {
TooManyRows,
TooManyCols,
InvalidChar(String),
Regex(Error),
InvalidLength,
}Expand description
error type for the Vestaboard board module
BoardError::TooManyRowsif there are too many rows in the inputBoardError::TooManyColsif there are too many columns in the inputBoardError::InvalidCharif there is an invalid character in the inputBoardError::Regexif there is an error with regex parsing of board dataBoardError::InvalidLengthif the length of the input is invalid
Variants
TooManyRows
too many rows in the input
TooManyCols
too many columns in the input
InvalidChar(String)
invalid character in the input, see the wrapped string for the invalid character
Regex(Error)
regex error (usually while parsing replacement of board data), see the wrapped regex::Error for more details
InvalidLength
invalid board length